@@ -11,3 +11,6 @@ def show_fingerprint():
         with open(args.certificate) as file:
             cert_str = file.read()
             print(certificate_fingerprint(cert_str))
+
+if __name__ == "__main__":
+    show_fingerprint()
\ No newline at end of file
